| Title: | Download Data from Moda |
|---|---|
| Description: | Connect to WFP's Moda platform to R, download data, and obtain the list of individuals with access to the project along with their access level. |
| Authors: | Idrissa DABO [aut, cre] |
| Maintainer: | Idrissa DABO <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 1.0.0 |
| Built: | 2026-06-07 09:54:43 UTC |
| Source: | https://github.com/cran/connectoModa |
This function allows users to download data from Moda
get_data_moda(form_id, Token)get_data_moda(form_id, Token)
form_id |
ID of users |
Token |
Token of users |
dataframe
## Not run: get_data_moda(56597, "9096b0028c4e68aa7a97122b889f3afe923b367b")## Not run: get_data_moda(56597, "9096b0028c4e68aa7a97122b889f3afe923b367b")
This function gives the list of users
get_user_moda(form_id, Token)get_user_moda(form_id, Token)
form_id |
ID of users |
Token |
Token of users |
dataframe
## Not run: get_user_moda(56597, "9096b0028c4e68aa7a97122b889f3afe923b367b")## Not run: get_user_moda(56597, "9096b0028c4e68aa7a97122b889f3afe923b367b")